---
title: "Hobby CAD shootout: Fusion 360"
description: I explore Autodesk Fusion 360 for hobbyist use. I put it through its paces and show strong points and weaknesses.
date: 2023-09-15T20:48:12.208Z
toc: true
software: Fusion 360
license: Limited free version for personal use, otherwise starts at $545/year/user
tags:
  - cad
  - cad-shootout
tldr: |
  I explore Autodesk Fusion 360 for hobbyist use. Fusion 360 is one of the most popular picks in the CAD world and its free version is stripped down but not to the point of making it unusable (for now). Definitely worth checking out.
keywords:
  - cad
  - fusion 360
lastmod: 2023-09-16T09:49:29.868Z
---

After looking at FreeCAD I wanted to wrap up the list of popular free choices before moving to the more exotic ones so Fusion 360 feels like a natural pick.

## Fusion 360

Fusion 360 is by far the most popular CAD software in 3D printing crowd. It initially launched as a trendy companion to Inventor, making most of its press due to being available on Mac OS X (most parametric CAD software like Inventor and Solidworks are Windows-only to this day) it somehow became the de-facto standard of 3D printing nerds worldwide, with tons of video-tutorials and learning material to find everywhere.

Fusion 360 requires online access (at least every 2 weeks) and has mandatory updates, I got prompted to either "Update now" or "Quit and update later", this means if any change for the worse comes later on (which they already have and totally will keep doing) you will have no choice to remain on the old version.

I will be looking at the free version of the software, with all its limitations.

### Free for personal use

Fusion 360 is normally paid software, it costs around $545/year/user (more or less depending if you pay monthly, yearly or every 3 years) plus any extra licensing cost from extra modules like simulation and machining.

There is a free trial and a "free for personal use" license that has several limitations, including:

- Non-commercial use only
- Limitations on import/export formats
- Most advanced parts of the software (CAM, drawings, simulations) are stripped down.

Like Onshape, you can apply for a "startup" license but there are no details other than a "Apply now" button and quite stringent requirements on what is considered a startup (e.g. you need investments).

There is also a very puzzling limitation: you can only have 10 editable documents at any one time. The 'editable' is important, as you can mark any document read-only and it will free up a slot (you can mark them editable again if you need). According to some annoyed people on Reddit it seems to have converted them into paying customers, so I guess it works?

Fusion 360 used to have a more permissive, more featureful license years ago when they had the "Startup/Hobbyist" license that covered most uses as long as your annual revenue was under US$100K. When Onshape switched to a full non-commercial license people were easy to flee to Fusion 360 somehow believing they would stick to their model. I ranted already about [my problem with these licenses]({{< relref "cad-shootout-onshape.md#the-problem-with-free-cad-software" >}} "The problem with “free” CAD software") and my belief is that they will get worse as these companies will try to extract more value from their existing userbase.

### Dark mode?

We hit our first CAD application without a dark mode. Fusion 360 is stuck in light mode all the time, thought you can switch up some of the colors of the 3D view to not make it a blaring flashlight into your eyes all the time. Someone [messed around with CSS files](https://github.com/OmegaRogue/FusionStyle) to make some parts of the UI dark but those changes haven't been updated in 3 years and they only cover offscreen menus so I don't think it's really worth bothering with.

### Lackluster defaults

Fusion 360 comes with very few keyboard shortcuts... or at least, a lot of mostly useless ones. Shortcuts are shared across the entire application so it seems the Fusion devs haphazardly assigned keys to random functions across the entire application. By "shared" I mean that there is no context to them. Pressing "E" in a sketch (which is what I'd expect trigger a Equal constraint) takes me out of the sketch and into the part workflow as it thinks I want to Extrude.

So what are the constraint shortcuts? There almost aren't any! Distance and Midpoint get one but everything else you have to set yourself. A user in the Autodesk forum pointed out that most SHIFT+key shortcuts are available, but it does mean that you'll have to spend some time setting them up before you can be decently productive at this.

## The trials

### Test drive: TooTallToby 05-07B - Curved gasket

This time the test drive part is TooTallToby's [05-07B - Curved gasket](https://www.youtube.com/watch?v=qTrq0x6WnrM).

Here is the video:

{{< rawhtml >}}
<video controls>
    <source src="/media/fusion360/ttt.webm" type='video/webm; codecs=av01.0.05M.08' />
    <source src="/media/fusion360/ttt.mp4" type='video/mp4; codecs="avc1.4D401E"' />
</video>
{{< /rawhtml >}}

The UI was a bit weird to wrestle with and there was a moment where I had trouble constraining a distance but otherwise, it was pretty smooth!

I had to set the material ahead of time and getting that sorted out was its own little mess but it's not *that* bad and honestly most of the existing materials are more than good enough unless you need specific stuff... and even then you do it once and then it just works.

This is the first software that has grid snapping on by default and I must say that I actually like it! I will definitely go back to Onshape and FreeCAD to explore if a similar option is there, though I have to say when working with parametric CAD it's hardly a requirement, if I'm going to set all the constraints anyway the grid is just helping me with the starting positions before the whole thing solves itself into the right shape.

All the functions I needed were easy to find and worked out of the box just like I expected, so no major complaints so far.

### Real world part: Tool stand

I have a lot of tools I use daily that I keep around in my desk, on their side, loosely. I would like a stand where they can be popped in and out and take less footprint.

![The tools](/media/fusion360/tools.jpg)

Let's design something for that!

![The tool holder of doom! Well, one half of it.](/media/fusion360/half.png)

I know, kinda boring and simple. But it mixes well with hardware I already had, and it works to show off the next few points.

### Export options

There are three ways to export this body, either "Save as mesh" or "3D print" have the same selection of export formats (at least on the free version) and...

![The "Save as mesh" dialog with all the formats supported](/media/fusion360/export.png)

Uh is that it?

The good news is I have no complaints about the exported 3MF file, looks sharp in PrusaSlicer with no polygon effect in the final print:

![The exported 3MF in PrusaSlicer](/media/fusion360/prusa.png)

Fear not, however, for there are more formats available! By going to File -> Export you can export the entire project as .STEP, several 3D formats such as OBJ/FBX and some other application formats such as Inventor (IPT) and Sketchup (SKP).

The method used to export doesn't really matter unless you want to export in STL: STL files from the "3D print" and "Save as mesh" are exported locally so as you'd expect you can just click Save and go while STL from the "Export" menu have to be queued and generated on Autodesk's cloud and will usually take a minute or so before it gets fully processed and ready for download... what's most confusing is that this is absolutely not the case for 3MF or STEP regardless of which workflow you use to export the part, it's all local and instant. What the hell Autodesk?

### Making drawings

The drawing workflow in Fusion is lovely! Their "Dimension" tool automatically understands the kind of dimension you're likely to want but you also get a plethora of manual dimension tool so you can choose if you prefer radius vs diameter, linear vs aligned etc. It even comes with a note tool that's so smart it auto-filled my countersunk hole dimension all by itself!

You can't add notes to the isometric drawing which is a bit of a shame but not unreasonable.

Once again I'm no engineer so my drawing leaves a lot to be desired plus I added a color filter to not make it a flashbang.

![The drawing of the previous part](/media/fusion360/drawing.png)

Worthy of note is that on the free version you are locked out of exporting drawings to any format, though you can sorta bypass this by printing them and using "Save to PDF" virtual printers like the ones built into Windows 10, just make sure to change the scale from "Fit to paper" to 1:1!

![No exporting for you... without a workaround](/media/fusion360/sub.png)

### Assembly

The assembly workflow is good! I still think Onshape has an edge in usability and the UI is just plain more intuitive, but Fusion 360 definitely wins in the sheer amount of feature libraries you get access to.

I find it quite entertaining that to get screws for assemblies it opens a web-view into McMaster-Carr's website (American hardware supplier, for my fellow non americans) and you're just supposed to find what you want and download the 3-D SAT model (it automagically gets added to the project after clicking Download, so it's not *that* sketchy).

![It gets the job done I guess?](/media/fusion360/mcmaster.png)

You won't get the more exotic features like exploded assemblies in the free version but I don't see why you couldn't just work around that manually.

### Sheet metal

Doing sheet metal parts is very simple! Fusion360 comes with its own "Sheet metal" tab full of tools for flanges and even threads.

As the exercise, I replicated TooTallToby's [21-03-08B - Post bracket](https://www.youtube.com/watch?v=ulFJTlNI3ls) and save for some trickery on the dimensions (not the software's fault but me falling to Toby's mischievous tricks) I got all done quite quickly and effortlessly.

![Toby ALMOST got me this time!](/media/fusion360/sm.png)

I once again exported the part to .STEP and ran it through a sheet metal online service UI just for sanity checking but haven't actually ordered it because that would make run me into poverty really quickly.

Unlike with drawings, Fusion 360 will let you flatten sheet metal parts and export a DXF of a flattened part.

Since I had trouble with this part I had a chance to bust out the measure tool! It was really quick and intuitive to use, helping me troubleshoot and identify the problem within a couple minutes. Thanks for that!

## Conclusion: A worthy favorite of many

I think Fusion's reputation is well earned. It requires some getting used to and to use efficiently you will need to spend some time setting shortcuts up and getting aquainted to its quirks but once you're familiar with it you could churn out parts very quickly!

I worry still about the future of the tool because of the company that maintains it, surely they will soon awaken again, pressured to try to convert more hobbyists into subscription users. Autodesk is a company dear to few and that number is not going up.

For the time being, as long as you're ok with the risk of having to jump ship, it's a solid pick! Remember to always back up all your projects in .STEP just in case.

{{< next-up "cad-shootout" "software" >}}
<h3>Interested in more?</h3>
<p>This series isn't over! The CAD shootout has a dedicated
<a href="/tags/cad-shootout/index.xml">RSS feed</a> you can follow to know when the next one drops!</p>
{{</ next-up >}}
